read<T> abstract method
T
read<T>()
T will find an instance saved under that class in the environment. Will
throw an error if none can be found.
Implementation
T read<T>();
T will find an instance saved under that class in the environment. Will
throw an error if none can be found.
T read<T>();